##  Viewing Discovered Microservices
On the integration page, you can view discovered microservices and their respective repositories. You can navigate to microservice fact sheets from here. If a repository is linked to a discovered microservice, clicking the repository name takes you to the manifest file. If no microservices are discovered for a repository, clicking the repository name directs you to the repository's root.
![GitHub Enterprise Integration Page Showing Discovered Microservices](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742aa467a44101493aaa6bdb9e5e10b_LowRes.png)
GitHub Enterprise Integration Page Showing Discovered Microservices
